@@ -42,7 +42,7 @@ class TracPost(Plugin):
 		print "New Ticket - " + str(ticket_id)
 	else:
 		print "Something Went Wrong"
-	
+	return self.render('<html>Test</html>')
 
     def actions(self, request, group, action_list, **kwargs):
 	action_list.append(('Send to Trac', 'http://google.com'))
@@ -50,5 +50,5 @@ class TracPost(Plugin):
 
 def start(request, group_id):
 	tp = Tracpost()
-	tp.send_message(group_id)
-	return "<xml>True</xml>"
+	response = tp.send_message(group_id)
+	return response
